.. QuadratiK documentation master file, created by
   sphinx-quickstart on Sun Nov 19 21:24:10 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

`Getting started <getting_started/index.html>`_
--------------------------------------------------

.. toctree::
   :hidden:
   :maxdepth: 4
   :titlesonly:

   getting_started/index.rst

`API Reference <api_reference/index.html>`_
---------------------------------------------

.. toctree::
   :hidden:
   :maxdepth: 4
   :titlesonly:

   api_reference/index.rst

`User Guide <user_guide/index.html>`_
---------------------------------------------

.. toctree::
   :hidden:
   :maxdepth: 4
   :titlesonly:

   user_guide/index.rst
